@@ -20,7 +20,7 @@ from zephyrus_sc2_parser.events import (
 from zephyrus_sc2_parser.dataclasses import GameData, Map
 from zephyrus_sc2_parser.game import Player
 from zephyrus_sc2_parser.gamedata.map_info import maps
-from zephyrus_sc2_parser.exceptions import MissingMmrError, PlayerCountError
+from zephyrus_sc2_parser.exceptions import PlayerCountError
 import pytz
 import logging
 
@@ -68,7 +68,7 @@ def _import_gamedata(protocol):
     )
 
 
-def _generate_initial_summary_stats(game, metadata, detailed_info, local=False):
+def _generate_initial_summary_stats(game, metadata, mmr_data):
     summary_stats = {
         'mmr': {1: 0, 2: 0},
         'avg_resource_collection_rate': {
@@ -102,12 +102,6 @@ def _generate_initial_summary_stats(game, metadata, detailed_info, local=False):
         'race': {1: {}, 2: {}},
     }
 
-    mmr_data = detailed_info['m_syncLobbyState']['m_userInitialData']
-    if 'm_scaledRating' not in mmr_data[0] or 'm_scaledRating' not in mmr_data[1]:
-        logger.warning('One or more players has no MMR')
-        if not local:
-            raise MissingMmrError('One or more players has no MMR. If you want to parse replays without MMR, add "local=True" as a keyword argument')
-
     # setting winner of the game
     for p in metadata['Players']:
         if p['Result'] == 'Win':
@@ -187,15 +181,15 @@ def _create_players(player_info, events, test_flag):
         player_obj.user_id = events[setup_index]['m_userId']
 
         player_obj = max(players, key=lambda x: x.player_id)
-        player_obj.player_id = events[setup_index+1]['m_playerId']
-        player_obj.user_id = events[setup_index+1]['m_userId']
+        player_obj.player_id = events[setup_index + 1]['m_playerId']
+        player_obj.user_id = events[setup_index + 1]['m_userId']
 
     # if both user_id's under 2 then the largest is set as 2 and the smallest is set as 1
     # specifically in that order to prevent assignment conflicts
     elif max(players) < 2:
         player_obj = max(players, key=lambda x: x.player_id)
-        player_obj.player_id = events[setup_index+1]['m_playerId']
-        player_obj.user_id = events[setup_index+1]['m_userId']
+        player_obj.player_id = events[setup_index + 1]['m_playerId']
+        player_obj.user_id = events[setup_index + 1]['m_userId']
 
         player_obj = min(players, key=lambda x: x.player_id)
         player_obj.player_id = events[setup_index]['m_playerId']
@@ -210,8 +204,8 @@ def _create_players(player_info, events, test_flag):
         player_obj.user_id = events[setup_index]['m_userId']
 
         player_obj = max(players, key=lambda x: x.player_id)
-        player_obj.player_id = events[setup_index+1]['m_playerId']
-        player_obj.user_id = events[setup_index+1]['m_userId']
+        player_obj.player_id = events[setup_index + 1]['m_playerId']
+        player_obj.user_id = events[setup_index + 1]['m_userId']
 
     players.sort(key=lambda x: x.player_id)
 
